dao

package
v1.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 18, 2019 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Migration

type Migration struct {
	Tag       string    `db:"tag"`
	Timestamp time.Time `db:"timestamp"`
}

Migration defines a migrations table record.

type Migrations

type Migrations []Migration

Migrations represents multiple dto migrations.

func (Migrations) Len

func (s Migrations) Len() int

Len returns length of migrations collection

func (Migrations) Less

func (s Migrations) Less(i, j int) bool

Less checks if migration at index i is less than migration at index j

func (Migrations) Swap

func (s Migrations) Swap(i, j int)

Swap swaps two migrations inside the collection by its indices

type Unittest

type Unittest struct {
	Value string `db:"value"`
}

Unittest defines a unittests table record.

Jump to