Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Migrations ¶
type Migrations []Migration
Migrations represents multiple dto migrations.
func (Migrations) Less ¶
func (s Migrations) Less(i, j int) bool
Less checks if migration at index i is less than migration at index j
func (Migrations) Swap ¶
func (s Migrations) Swap(i, j int)
Swap swaps two migrations inside the collection by its indices
Click to show internal directories.
Click to hide internal directories.